@@ -1,5 +1,5 @@
 //
-// Copyright (c) 2012-2021 Red Hat, Inc.
+// Copyright (c) 2019-2021 Red Hat, Inc.
 // This program and the accompanying materials are made
 // available under the terms of the Eclipse Public License 2.0
 // which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -9,12 +9,12 @@
 // Contributors:
 //   Red Hat, Inc. - initial API and implementation
 //
+
 package che
 
 import (
 	"context"
 	"fmt"
-	"io/ioutil"
 	"os"
 	"strconv"
 
@@ -25,7 +25,9 @@ import (
 
 	chev1alpha1 "github.com/che-incubator/kubernetes-image-puller-operator/api/v1alpha1"
 	"github.com/golang/mock/gomock"
+	crdv1 "k8s.io/apiextensions-apiserver/pkg/apis/apiextensions/v1"
 
+	devworkspace "github.com/eclipse-che/che-operator/pkg/deploy/dev-workspace"
 	identity_provider "github.com/eclipse-che/che-operator/pkg/deploy/identity-provider"
 	"github.com/google/go-cmp/cmp"
 
@@ -35,7 +37,7 @@ import (
 	console "github.com/openshift/api/console/v1"
 
 	orgv1 "github.com/eclipse-che/che-operator/api/v1"
-	oauth "github.com/openshift/api/oauth/v1"
+	oauthv1 "github.com/openshift/api/oauth/v1"
 	routev1 "github.com/openshift/api/route/v1"
 	userv1 "github.com/openshift/api/user/v1"
 	operatorsv1 "github.com/operator-framework/api/pkg/operators/v1"
@@ -46,8 +48,8 @@ import (
 	appsv1 "k8s.io/api/apps/v1"
 	corev1 "k8s.io/api/core/v1"
 	rbac "k8s.io/api/rbac/v1"
+	"k8s.io/utils/pointer"
 
-	che_mocks "github.com/eclipse-che/che-operator/mocks/controllers"
 	"k8s.io/apimachinery/pkg/api/errors"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/runtime"
@@ -63,66 +65,14 @@ import (
 	logf "sigs.k8s.io/controller-runtime/pkg/log"
 	"sigs.k8s.io/controller-runtime/pkg/log/zap"
 	"sigs.k8s.io/controller-runtime/pkg/reconcile"
-	"sigs.k8s.io/yaml"
 
 	"testing"
 )
 
 var (
-	namespace        = "eclipse-che"
-	nonEmptyUserList = &userv1.UserList{
-		Items: []userv1.User{
-			{
-				ObjectMeta: metav1.ObjectMeta{
-					Name: "user1",
-				},
-			},
-			{
-				ObjectMeta: metav1.ObjectMeta{
-					Name: "user2",
-				},
-			},
-		},
-	}
-	oAuthClient                  = &oauth.OAuthClient{}
-	oAuthWithNoIdentityProviders = &configv1.OAuth{
-		ObjectMeta: metav1.ObjectMeta{
-			Name: "cluster",
-			// Namespace: namespace,
-		},
-	}
-	oAuthWithIdentityProvider = &configv1.OAuth{
-		ObjectMeta: metav1.ObjectMeta{
-			Name: "cluster",
-			// Namespace: namespace,
-		},
-		Spec: configv1.OAuthSpec{
-			IdentityProviders: []configv1.IdentityProvider{
-				{
-					Name: "htpasswd",
-				},
-			},
-		},
-	}
-	route = &routev1.Route{}
-	proxy = &configv1.Proxy{
-		ObjectMeta: metav1.ObjectMeta{
-			Name: "cluster",
-		},
-	}
+	namespace = "eclipse-che"
 )
 
-func init() {
-	operator := &appsv1.Deployment{}
-	data, err := ioutil.ReadFile("../../config/manager/manager.yaml")
-	yaml.Unmarshal(data, operator)
-	if err == nil {
-		for _, env := range operator.Spec.Template.Spec.Containers[0].Env {
-			os.Setenv(env.Name, env.Value)
-		}
-	}
-}
-
 func TestNativeUserModeEnabled(t *testing.T) {
 	type testCase struct {
 		name                    string
@@ -131,7 +81,6 @@ func TestNativeUserModeEnabled(t *testing.T) {
 		devworkspaceEnabled     bool
 		initialNativeUserValue  *bool
 		expectedNativeUserValue *bool
-		mockFunction            func(ctrl *gomock.Controller, crNamespace string, usernamePrefix string) *che_mocks.MockOpenShiftOAuthUserHandler
 	}
 
 	testCases := []testCase{
@@ -140,21 +89,21 @@ func TestNativeUserModeEnabled(t *testing.T) {
 			isOpenshift:             true,
 			devworkspaceEnabled:     true,
 			initialNativeUserValue:  nil,
-			expectedNativeUserValue: util.NewBoolPointer(true),
+			expectedNativeUserValue: pointer.BoolPtr(true),
 		},
 		{
 			name:                    "codeready-operator should use nativeUserMode value from initial CR",
 			isOpenshift:             true,
 			devworkspaceEnabled:     true,
-			initialNativeUserValue:  util.NewBoolPointer(false),
-			expectedNativeUserValue: util.NewBoolPointer(false),
+			initialNativeUserValue:  pointer.BoolPtr(false),
+			expectedNativeUserValue: pointer.BoolPtr(false),
 		},
 		{
 			name:                    "codeready-operator should use nativeUserMode value from initial CR",
 			isOpenshift:             true,
 			devworkspaceEnabled:     true,
-			initialNativeUserValue:  util.NewBoolPointer(true),
-			expectedNativeUserValue: util.NewBoolPointer(true),
+			initialNativeUserValue:  pointer.BoolPtr(true),
+			expectedNativeUserValue: pointer.BoolPtr(true),
 		},
 		{
 			name:                    "codeready-operator should not modify nativeUserMode when not on openshift",
@@ -178,16 +127,23 @@ func TestNativeUserModeEnabled(t *testing.T) {
 
 			scheme := scheme.Scheme
 			orgv1.SchemeBuilder.AddToScheme(scheme)
-			scheme.AddKnownTypes(routev1.GroupVersion, route)
-			scheme.AddKnownTypes(oauth.SchemeGroupVersion, oAuthClient)
+			scheme.AddKnownTypes(routev1.GroupVersion, &routev1.Route{})
+			scheme.AddKnownTypes(oauthv1.SchemeGroupVersion, &oauthv1.OAuthClient{})
 			scheme.AddKnownTypes(configv1.SchemeGroupVersion, &configv1.Proxy{})
-			initCR := InitCheWithSimpleCR().DeepCopy()
-			testCase.initObjects = append(testCase.initObjects, initCR)
+			scheme.AddKnownTypes(crdv1.SchemeGroupVersion, &crdv1.CustomResourceDefinition{})
 
+			initCR := InitCheWithSimpleCR().DeepCopy()
 			initCR.Spec.DevWorkspace.Enable = testCase.devworkspaceEnabled
 			initCR.Spec.Auth.NativeUserMode = testCase.initialNativeUserValue
+			testCase.initObjects = append(testCase.initObjects, initCR)
+
 			util.IsOpenShift = testCase.isOpenshift
 
+			// reread templates (workaround after setting IsOpenShift value)
+			devworkspace.DevWorkspaceTemplates = devworkspace.DevWorkspaceTemplatesPath()
+			devworkspace.DevWorkspaceIssuerFile = devworkspace.DevWorkspaceTemplates + "/devworkspace-controller-selfsigned-issuer.Issuer.yaml"
+			devworkspace.DevWorkspaceCertificateFile = devworkspace.DevWorkspaceTemplates + "/devworkspace-controller-serving-cert.Certificate.yaml"
+
 			cli := fake.NewFakeClientWithScheme(scheme, testCase.initObjects...)
 			nonCachedClient := fake.NewFakeClientWithScheme(scheme, testCase.initObjects...)
 			clientSet := fakeclientset.NewSimpleClientset()
@@ -233,224 +189,6 @@ func TestNativeUserModeEnabled(t *testing.T) {
 	}
 }
 
-func TestCaseAutoDetectOAuth(t *testing.T) {
-	type testCase struct {
-		name                                string
-		initObjects                         []runtime.Object
-		isOpenshift3                        bool
-		initialOAuthValue                   *bool
-		oAuthExpected                       *bool
-		initialOpenShiftOAuthUserEnabled    *bool
-		OpenShiftOAuthUserCredentialsSecret string
-		mockFunction                        func(ctrl *gomock.Controller, crNamespace string, usernamePrefix string) *che_mocks.MockOpenShiftOAuthUserHandler
-	}
-
-	testCases := []testCase{
-		{
-			name: "codeready-operator should auto enable oAuth when Che CR with oAuth nil value on the Openshift 3 with users > 0",
-			initObjects: []runtime.Object{
-				nonEmptyUserList,
-				&oauth.OAuthClient{},
-			},
-			isOpenshift3:      true,
-			initialOAuthValue: nil,
-			oAuthExpected:     util.NewBoolPointer(true),
-		},
-		{
-			name: "codeready-operator should auto disable oAuth when Che CR with nil oAuth on the Openshift 3 with no users",
-			initObjects: []runtime.Object{
-				&userv1.UserList{},
-				&oauth.OAuthClient{},
-			},
-			isOpenshift3:      true,
-			initialOAuthValue: util.NewBoolPointer(false),
-			oAuthExpected:     util.NewBoolPointer(false),
-		},
-		{
-			name: "codeready-operator should respect oAuth = true even if there no users on the Openshift 3",
-			initObjects: []runtime.Object{
-				&userv1.UserList{},
-				&oauth.OAuthClient{},
-			},
-			isOpenshift3:      true,
-			initialOAuthValue: util.NewBoolPointer(true),
-			oAuthExpected:     util.NewBoolPointer(true),
-		},
-		{
-			name: "codeready-operator should respect oAuth = true even if there are some users on the Openshift 3",
-			initObjects: []runtime.Object{
-				nonEmptyUserList,
-				&oauth.OAuthClient{},
-			},
-			isOpenshift3:      true,
-			initialOAuthValue: util.NewBoolPointer(true),
-			oAuthExpected:     util.NewBoolPointer(true),
-		},
-		{
-			name: "codeready-operator should respect oAuth = false even if there are some users on the Openshift 3",
-			initObjects: []runtime.Object{
-				nonEmptyUserList,
-				&oauth.OAuthClient{},
-			},
-			isOpenshift3:      true,
-			initialOAuthValue: util.NewBoolPointer(false),
-			oAuthExpected:     util.NewBoolPointer(false),
-		},
-		{
-			name: "codeready-operator should respect oAuth = false even if no users on the Openshift 3",
-			initObjects: []runtime.Object{
-				&userv1.UserList{},
-				&oauth.OAuthClient{},
-			},
-			isOpenshift3:      true,
-			initialOAuthValue: util.NewBoolPointer(false),
-			oAuthExpected:     util.NewBoolPointer(false),
-		},
-		{
-			name: "codeready-operator should auto enable oAuth when Che CR with nil value on the Openshift 4 with identity providers",
-			initObjects: []runtime.Object{
-				oAuthWithIdentityProvider,
-				proxy,
-			},
-			isOpenshift3:      false,
-			initialOAuthValue: nil,
-			oAuthExpected:     util.NewBoolPointer(true),
-		},
-		{
-			name: "codeready-operator should respect oAuth = true even if there no indentity providers on the Openshift 4",
-			initObjects: []runtime.Object{
-				oAuthWithNoIdentityProviders,
-				proxy,
-			},
-			isOpenshift3:                     false,
-			initialOAuthValue:                util.NewBoolPointer(true),
-			oAuthExpected:                    util.NewBoolPointer(true),
-			initialOpenShiftOAuthUserEnabled: util.NewBoolPointer(true),
-		},
-		{
-			name: "codeready-operator should not create initial user and enable oAuth, when oAuth = true, initialOpenShiftOAuthUserEnabled = true and there no indentity providers on the Openshift 4",
-			initObjects: []runtime.Object{
-				oAuthWithNoIdentityProviders,
-				proxy,
-			},
-			isOpenshift3:                     false,
-			initialOAuthValue:                util.NewBoolPointer(true),
-			oAuthExpected:                    util.NewBoolPointer(true),
-			initialOpenShiftOAuthUserEnabled: util.NewBoolPointer(false),
-		},
-		{
-			name: "codeready-operator should respect oAuth = true even if there are some users on the Openshift 4",
-			initObjects: []runtime.Object{
-				oAuthWithIdentityProvider,
-				proxy,
-			},
-			isOpenshift3:                     true,
-			initialOAuthValue:                util.NewBoolPointer(true),
-			oAuthExpected:                    util.NewBoolPointer(true),
-			initialOpenShiftOAuthUserEnabled: util.NewBoolPointer(true),
-		},
-		{
-			name: "codeready-operator should respect oAuth = false even if there no indentity providers on the Openshift 4",
-			initObjects: []runtime.Object{
-				oAuthWithNoIdentityProviders,
-				proxy,
-			},
-			isOpenshift3:      true,
-			initialOAuthValue: util.NewBoolPointer(false),
-			oAuthExpected:     util.NewBoolPointer(false),
-		},
-		{
-			name: "codeready-operator should respect oAuth = false even if there are some users on the Openshift 4",
-			initObjects: []runtime.Object{
-				oAuthWithIdentityProvider,
-				proxy,
-			},
-			isOpenshift3:      true,
-			initialOAuthValue: util.NewBoolPointer(false),
-			oAuthExpected:     util.NewBoolPointer(false),
-		},
-		{
-			name:                             "codeready-operator should auto disable oAuth on error retieve identity providers",
-			initObjects:                      []runtime.Object{},
-			isOpenshift3:                     true,
-			initialOAuthValue:                nil,
-			initialOpenShiftOAuthUserEnabled: util.NewBoolPointer(true),
-			oAuthExpected:                    util.NewBoolPointer(false),
-		},
-	}
-	for _, testCase := range testCases {
-		t.Run(testCase.name, func(t *testing.T) {
-			logf.SetLogger(zap.New(zap.WriteTo(os.Stdout), zap.UseDevMode(true)))
-
-			scheme := scheme.Scheme
-			orgv1.SchemeBuilder.AddToScheme(scheme)
-			scheme.AddKnownTypes(oauth.SchemeGroupVersion, oAuthClient)
-			scheme.AddKnownTypes(userv1.SchemeGroupVersion, &userv1.UserList{}, &userv1.User{})
-			scheme.AddKnownTypes(configv1.SchemeGroupVersion, &configv1.OAuth{}, &configv1.Proxy{})
-			scheme.AddKnownTypes(routev1.GroupVersion, route)
-			scheme.AddKnownTypes(configv1.GroupVersion, &configv1.Proxy{})
-			initCR := InitCheWithSimpleCR().DeepCopy()
-			initCR.Spec.Auth.OpenShiftoAuth = testCase.initialOAuthValue
-			testCase.initObjects = append(testCase.initObjects, initCR)
-			initCR.Spec.Auth.InitialOpenShiftOAuthUser = testCase.initialOpenShiftOAuthUserEnabled
-
-			cli := fake.NewFakeClientWithScheme(scheme, testCase.initObjects...)
-			nonCachedClient := fake.NewFakeClientWithScheme(scheme, testCase.initObjects...)
-			clientSet := fakeclientset.NewSimpleClientset()
-			fakeDiscovery, ok := clientSet.Discovery().(*fakeDiscovery.FakeDiscovery)
-			fakeDiscovery.Fake.Resources = []*metav1.APIResourceList{}
-
-			if !ok {
-				t.Fatal("Error creating fake discovery client")
-			}
-
-			// prepare mocks
-			var userHandlerMock *che_mocks.MockOpenShiftOAuthUserHandler
-			if testCase.mockFunction != nil {
-				ctrl := gomock.NewController(t)
-				userHandlerMock = testCase.mockFunction(ctrl, initCR.Namespace, deploy.DefaultCheFlavor(initCR))
-				defer ctrl.Finish()
-			}
-
-			r := NewReconciler(cli, nonCachedClient, fakeDiscovery, scheme, "")
-			r.userHandler = userHandlerMock
-			r.tests = true
-
-			req := reconcile.Request{
-				NamespacedName: types.NamespacedName{
-					Name:      os.Getenv("CHE_FLAVOR"),
-					Namespace: namespace,
-				},
-			}
-
-			util.IsOpenShift = true
-			util.IsOpenShift4 = !testCase.isOpenshift3
-
-			_, err := r.Reconcile(context.TODO(), req)
-			if err != nil {
-				t.Fatalf("Error reconciling: %v", err)
-			}
-
-			cheCR := &orgv1.CheCluster{}
-			if err := r.client.Get(context.TODO(), types.NamespacedName{Name: os.Getenv("CHE_FLAVOR"), Namespace: namespace}, cheCR); err != nil {
-				t.Errorf("CR not found")
-			}
-
-			if cheCR.Spec.Auth.OpenShiftoAuth == nil {
-				t.Error("OAuth should not stay with nil value.")
-			}
-
-			if *cheCR.Spec.Auth.OpenShiftoAuth != *testCase.oAuthExpected {
-				t.Errorf("Openshift oAuth should be %t", *testCase.oAuthExpected)
-			}
-
-			if cheCR.Status.OpenShiftOAuthUserCredentialsSecret != testCase.OpenShiftOAuthUserCredentialsSecret {
-				t.Errorf("Expected initial openshift oAuth user secret %s in the CR status", testCase.OpenShiftOAuthUserCredentialsSecret)
-			}
-		})
-	}
-}
-
 func TestEnsureServerExposureStrategy(t *testing.T) {
 	type testCase struct {
 		name                string
@@ -515,6 +253,8 @@ func TestEnsureServerExposureStrategy(t *testing.T) {
 				},
 			}
 
+			util.IsOpenShift = true
+			util.IsOpenShift4 = false
 			_, err := r.Reconcile(context.TODO(), req)
 			if err != nil {
 				t.Fatalf("Error reconciling: %v", err)
@@ -796,9 +536,9 @@ func TestCheController(t *testing.T) {
 	}
 
 	clusterAPI := deploy.ClusterAPI{
-		Client:          r.client,
-		NonCachedClient: r.client,
-		Scheme:          r.Scheme,
+		Client:           r.client,
+		NonCachingClient: r.client,
+		Scheme:           r.Scheme,
 	}
 
 	deployContext := &deploy.DeployContext{
@@ -814,7 +554,7 @@ func TestCheController(t *testing.T) {
 	}
 	oAuthClientName := cheCR.Spec.Auth.OAuthClientName
 	oauthSecret := cheCR.Spec.Auth.OAuthSecret
-	oAuthClient := &oauth.OAuthClient{}
+	oAuthClient := &oauthv1.OAuthClient{}
 	if err = r.client.Get(context.TODO(), types.NamespacedName{Name: oAuthClientName, Namespace: ""}, oAuthClient); err != nil {
 		t.Errorf("Failed to Get oAuthClient %s: %s", oAuthClient.Name, err)
 	}
@@ -887,7 +627,7 @@ func TestCheController(t *testing.T) {
 		t.Fatal("Failed to reconcile oAuthClient")
 	}
 	oauthClientName := cheCR.Spec.Auth.OAuthClientName
-	oauthClient := &oauth.OAuthClient{}
+	oauthClient := &oauthv1.OAuthClient{}
 	err = r.nonCachedClient.Get(context.TODO(), types.NamespacedName{Name: oAuthClientName}, oauthClient)
 	if err == nil {
 		t.Fatalf("OauthClient %s has not been deleted", oauthClientName)
@@ -1012,13 +752,13 @@ func TestShouldDelegatePermissionsForCheWorkspaces(t *testing.T) {
 
 			scheme := scheme.Scheme
 			orgv1.SchemeBuilder.AddToScheme(scheme)
-			scheme.AddKnownTypes(oauth.SchemeGroupVersion, oAuthClient)
+			scheme.AddKnownTypes(oauthv1.SchemeGroupVersion, &oauthv1.OAuthClient{})
 			scheme.AddKnownTypes(userv1.SchemeGroupVersion, &userv1.UserList{}, &userv1.User{})
 			scheme.AddKnownTypes(configv1.SchemeGroupVersion, &configv1.OAuth{}, &configv1.Proxy{})
-			scheme.AddKnownTypes(routev1.GroupVersion, route)
+			scheme.AddKnownTypes(routev1.GroupVersion, &routev1.Route{})
 
 			initCR := testCase.checluster
-			initCR.Spec.Auth.OpenShiftoAuth = util.NewBoolPointer(false)
+			initCR.Spec.Auth.OpenShiftoAuth = pointer.BoolPtr(false)
 			testCase.initObjects = append(testCase.initObjects, initCR)
 
 			cli := fake.NewFakeClientWithScheme(scheme, testCase.initObjects...)
@@ -1110,12 +850,12 @@ func TestShouldDelegatePermissionsForCheWorkspaces(t *testing.T) {
 func Init() (client.Client, discovery.DiscoveryInterface, runtime.Scheme) {
 	objs, ds, scheme := createAPIObjects()
 
-	oAuthClient := &oauth.OAuthClient{}
+	oAuthClient := &oauthv1.OAuthClient{}
 	users := &userv1.UserList{}
 	user := &userv1.User{}
 
 	// Register operator types with the runtime scheme
-	scheme.AddKnownTypes(oauth.SchemeGroupVersion, oAuthClient)
+	scheme.AddKnownTypes(oauthv1.SchemeGroupVersion, oAuthClient)
 	scheme.AddKnownTypes(userv1.SchemeGroupVersion, users, user)
 	scheme.AddKnownTypes(configv1.SchemeGroupVersion, &configv1.Proxy{})
 
@@ -1192,7 +932,7 @@ func InitCheWithSimpleCR() *orgv1.CheCluster {
 				CheWorkspaceClusterRole: "cluster-admin",
 			},
 			Auth: orgv1.CheClusterSpecAuth{
-				OpenShiftoAuth: util.NewBoolPointer(false),
+				OpenShiftoAuth: pointer.BoolPtr(false),
 			},
 		},
 	}
