@@ -1,5 +1,5 @@
 //
-// Copyright (c) 2021 Red Hat, Inc.
+// Copyright (c) 2019-2021 Red Hat, Inc.
 // This program and the accompanying materials are made
 // available under the terms of the Eclipse Public License 2.0
 // which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -22,6 +22,7 @@ import (
 
 	orgv1 "github.com/eclipse-che/che-operator/api/v1"
 	"github.com/eclipse-che/che-operator/pkg/deploy"
+	"github.com/eclipse-che/che-operator/pkg/deploy/tls"
 	"github.com/eclipse-che/che-operator/pkg/util"
 	corev1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/types"
@@ -60,7 +61,7 @@ func createBackupMetadataFile(bctx *BackupContext, destDir string) (bool, error)
 
 	var appsDomain string
 	if util.IsOpenShift {
-		host, err := util.GetRouterCanonicalHostname(bctx.r.client, bctx.namespace)
+		host, err := util.GetRouterCanonicalHostname(bctx.r.nonCachingClient, bctx.namespace)
 		if err != nil {
 			return false, err
 		}
@@ -129,7 +130,7 @@ func prepareDirectory(destDir string) error {
 func backupCheCR(bctx *BackupContext, destDir string) (bool, error) {
 	cheCR := &orgv1.CheCluster{}
 	namespacedName := types.NamespacedName{Namespace: bctx.namespace, Name: bctx.cheCR.GetName()}
-	if err := bctx.r.client.Get(context.TODO(), namespacedName, cheCR); err != nil {
+	if err := bctx.r.cachingClient.Get(context.TODO(), namespacedName, cheCR); err != nil {
 		return false, err
 	}
 	util.ClearMetadata(&cheCR.ObjectMeta)
@@ -220,11 +221,7 @@ func backupConfigMaps(bctx *BackupContext, destDir string) (bool, error) {
 		return true, err
 	}
 
-	fakeDeployContext := &deploy.DeployContext{
-		ClusterAPI: deploy.ClusterAPI{Client: bctx.r.client},
-		CheCluster: bctx.cheCR,
-	}
-	caBundlesConfigmaps, err := deploy.GetCACertsConfigMaps(fakeDeployContext)
+	caBundlesConfigmaps, err := tls.GetCACertsConfigMaps(bctx.r.nonCachingClient, bctx.cheCR.GetNamespace())
 	if err != nil {
 		return false, err
 	}
@@ -268,7 +265,7 @@ func backupSecrets(bctx *BackupContext, destDir string) (bool, error) {
 	for _, secretName := range secretsNames {
 		secret := &corev1.Secret{}
 		namespacedName := types.NamespacedName{Name: secretName, Namespace: bctx.namespace}
-		if err := bctx.r.client.Get(context.TODO(), namespacedName, secret); err != nil {
+		if err := bctx.r.nonCachingClient.Get(context.TODO(), namespacedName, secret); err != nil {
 			return false, err
 		}
 
