@@ -1,5 +1,5 @@
 //
-// Copyright (c) 2021 Red Hat, Inc.
+// Copyright (c) 2019-2021 Red Hat, Inc.
 // This program and the accompanying materials are made
 // available under the terms of the Eclipse Public License 2.0
 // which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -38,7 +38,7 @@ func NewRestoreContext(r *ReconcileCheClusterRestore, restoreCR *chev1.CheCluste
 		return nil, err
 	}
 
-	cheCR, CRCount, err := util.FindCheClusterCRInNamespace(r.client, namespace)
+	cheCR, CRCount, err := util.FindCheClusterCRInNamespace(r.cachingClient, namespace)
 	if err != nil {
 		// Check if Che CR is present
 		if CRCount > 0 {
