@@ -1,5 +1,5 @@
 //
-// Copyright (c) 2021 Red Hat, Inc.
+// Copyright (c) 2019-2021 Red Hat, Inc.
 // This program and the accompanying materials are made
 // available under the terms of the Eclipse Public License 2.0
 // which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -122,7 +122,7 @@ func (d *Dashboard) createGatewayConfig() *gateway.TraefikConfig {
 		10,
 		"http://"+d.component+":8080",
 		[]string{})
-	if util.IsNativeUserModeEnabled(d.deployContext.CheCluster) {
+	if util.IsOpenShift && d.deployContext.CheCluster.IsNativeUserModeEnabled() {
 		cfg.AddAuthHeaderRewrite(d.component)
 	}
 	return cfg
