@@ -1,5 +1,5 @@
 //
-// Copyright (c) 2021 Red Hat, Inc.
+// Copyright (c) 2019-2021 Red Hat, Inc.
 // This program and the accompanying materials are made
 // available under the terms of the Eclipse Public License 2.0
 // which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -53,9 +53,9 @@ func TestDashboardOpenShift(t *testing.T) {
 	deployContext := &deploy.DeployContext{
 		CheCluster: cheCluster,
 		ClusterAPI: deploy.ClusterAPI{
-			Client:          cli,
-			NonCachedClient: cli,
-			Scheme:          scheme.Scheme,
+			Client:           cli,
+			NonCachingClient: cli,
+			Scheme:           scheme.Scheme,
 		},
 	}
 
@@ -93,9 +93,9 @@ func TestDashboardKubernetes(t *testing.T) {
 	deployContext := &deploy.DeployContext{
 		CheCluster: cheCluster,
 		ClusterAPI: deploy.ClusterAPI{
-			Client:          cli,
-			NonCachedClient: cli,
-			Scheme:          scheme.Scheme,
+			Client:           cli,
+			NonCachingClient: cli,
+			Scheme:           scheme.Scheme,
 		},
 	}
 
@@ -133,9 +133,9 @@ func TestDashboardClusterRBACFinalizerOnKubernetes(t *testing.T) {
 	deployContext := &deploy.DeployContext{
 		CheCluster: cheCluster,
 		ClusterAPI: deploy.ClusterAPI{
-			Client:          cli,
-			NonCachedClient: cli,
-			Scheme:          scheme.Scheme,
+			Client:           cli,
+			NonCachingClient: cli,
+			Scheme:           scheme.Scheme,
 		},
 	}
 
