@@ -1,5 +1,5 @@
 //
-// Copyright (c) 2020-2020 Red Hat, Inc.
+// Copyright (c) 2019-2021 Red Hat, Inc.
 // This program and the accompanying materials are made
 // available under the terms of the Eclipse Public License 2.0
 // which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -26,17 +26,18 @@ type ProvisioningStatus struct {
 }
 
 type DeployContext struct {
-	CheCluster     *orgv1.CheCluster
-	ClusterAPI     ClusterAPI
-	Proxy          *Proxy
-	DefaultCheHost string
+	CheCluster              *orgv1.CheCluster
+	ClusterAPI              ClusterAPI
+	Proxy                   *Proxy
+	DefaultCheHost          string
+	IsSelfSignedCertificate bool
 }
 
 type ClusterAPI struct {
-	Client          client.Client
-	NonCachedClient client.Client
-	DiscoveryClient discovery.DiscoveryInterface
-	Scheme          *runtime.Scheme
+	Client           client.Client
+	NonCachingClient client.Client
+	DiscoveryClient  discovery.DiscoveryInterface
+	Scheme           *runtime.Scheme
 }
 
 type Proxy struct {
