@@ -1,5 +1,5 @@
 //
-// Copyright (c) 2018-2020 Red Hat, Inc.
+// Copyright (c) 2019-2021 Red Hat, Inc.
 // This program and the accompanying materials are made
 // available under the terms of the Eclipse Public License 2.0
 // which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -69,6 +69,7 @@ const (
 	DefaultCheMetricsPort          = int32(8087)
 	DefaultCheDebugPort            = int32(8000)
 	DefaultPostgresVolumeClaimName = "postgres-data"
+	DefaultPostgresPvcClaimSize    = "1Gi"
 
 	DefaultJavaOpts          = "-XX:MaxRAMPercentage=85.0"
 	DefaultWorkspaceJavaOpts = "-XX:MaxRAM=150m -XX:MaxRAMFraction=2 -XX:+UseParallelGC " +
@@ -125,6 +126,12 @@ const (
 	// CheServiceAccountName - service account name for che-server.
 	CheServiceAccountName = "che"
 
+	// Name of the secret that holds self-signed certificate for git connections
+	GitSelfSignedCertsConfigMapName = "che-git-self-signed-cert"
+
+	CheTLSSelfSignedCertificateSecretName = "self-signed-certificate"
+	DefaultCheTLSSecretName               = "che-tls"
+
 	// limits
 	DefaultDashboardMemoryLimit   = "256Mi"
 	DefaultDashboardMemoryRequest = "32Mi"
