@@ -1,5 +1,5 @@
 //
-// Copyright (c) 2021 Red Hat, Inc.
+// Copyright (c) 2019-2021 Red Hat, Inc.
 // This program and the accompanying materials are made
 // available under the terms of the Eclipse Public License 2.0
 // which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -124,11 +124,15 @@ func TestReconcileDevWorkspace(t *testing.T) {
 	for _, testCase := range testCases {
 		t.Run(testCase.name, func(t *testing.T) {
 			deployContext := deploy.GetTestDeployContext(testCase.cheCluster, []runtime.Object{})
-			deployContext.ClusterAPI.Scheme.AddKnownTypes(crdv1.SchemeGroupVersion, &crdv1.CustomResourceDefinition{})
-			deployContext.ClusterAPI.Scheme.AddKnownTypes(operatorsv1alpha1.SchemeGroupVersion, &operatorsv1alpha1.Subscription{})
 
 			util.IsOpenShift = testCase.IsOpenShift
 			util.IsOpenShift4 = testCase.IsOpenShift4
+
+			// reread templates (workaround after setting IsOpenShift value)
+			DevWorkspaceTemplates = DevWorkspaceTemplatesPath()
+			DevWorkspaceIssuerFile = DevWorkspaceTemplates + "/devworkspace-controller-selfsigned-issuer.Issuer.yaml"
+			DevWorkspaceCertificateFile = DevWorkspaceTemplates + "/devworkspace-controller-serving-cert.Certificate.yaml"
+
 			err := os.Setenv("ALLOW_DEVWORKSPACE_ENGINE", "true")
 			assert.NoError(t, err)
 
@@ -243,7 +247,7 @@ func TestReconcileWhenWebTerminalSubscriptionExists(t *testing.T) {
 
 	// verify that DWO is not provisioned
 	namespace := &corev1.Namespace{}
-	err = deployContext.ClusterAPI.NonCachedClient.Get(context.TODO(), types.NamespacedName{Name: DevWorkspaceNamespace}, namespace)
+	err = deployContext.ClusterAPI.NonCachingClient.Get(context.TODO(), types.NamespacedName{Name: DevWorkspaceNamespace}, namespace)
 	assert.True(t, k8sErrors.IsNotFound(err))
 }
 
@@ -352,7 +356,7 @@ func TestReconcileDevWorkspaceIfManagedDWONamespaceExists(t *testing.T) {
 		},
 	}
 	deployContext := deploy.GetTestDeployContext(cheCluster, []runtime.Object{})
-	err := deployContext.ClusterAPI.NonCachedClient.Create(context.TODO(), dwoNamespace)
+	err := deployContext.ClusterAPI.NonCachingClient.Create(context.TODO(), dwoNamespace)
 	assert.NoError(t, err)
 
 	exists, err := deploy.Get(deployContext,
@@ -400,7 +404,7 @@ func TestReconcileDevWorkspaceIfManagedDWOShouldBeTakenUnderControl(t *testing.T
 	}
 	deployContext := deploy.GetTestDeployContext(cheCluster, []runtime.Object{})
 	deployContext.ClusterAPI.Scheme.AddKnownTypes(crdv1.SchemeGroupVersion, &crdv1.CustomResourceDefinition{})
-	err := deployContext.ClusterAPI.NonCachedClient.Create(context.TODO(), dwoNamespace)
+	err := deployContext.ClusterAPI.NonCachingClient.Create(context.TODO(), dwoNamespace)
 	assert.NoError(t, err)
 
 	exists, err := deploy.Get(deployContext,
@@ -467,9 +471,9 @@ func TestReconcileDevWorkspaceIfManagedDWOShouldNotBeTakenUnderControl(t *testin
 	}
 	deployContext := deploy.GetTestDeployContext(cheCluster, []runtime.Object{})
 	deployContext.ClusterAPI.Scheme.AddKnownTypes(crdv1.SchemeGroupVersion, &crdv1.CustomResourceDefinition{})
-	err := deployContext.ClusterAPI.NonCachedClient.Create(context.TODO(), dwoNamespace)
+	err := deployContext.ClusterAPI.NonCachingClient.Create(context.TODO(), dwoNamespace)
 	assert.NoError(t, err)
-	err = deployContext.ClusterAPI.NonCachedClient.Create(context.TODO(), cheCluster2)
+	err = deployContext.ClusterAPI.NonCachingClient.Create(context.TODO(), cheCluster2)
 	assert.NoError(t, err)
 
 	exists, err := deploy.Get(deployContext,
