@@ -1,5 +1,5 @@
 //
-// Copyright (c) 2012-2019 Red Hat, Inc.
+// Copyright (c) 2019-2021 Red Hat, Inc.
 // This program and the accompanying materials are made
 // available under the terms of the Eclipse Public License 2.0
 // which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -19,6 +19,7 @@ import (
 	"github.com/eclipse-che/che-operator/pkg/deploy"
 	identity_provider "github.com/eclipse-che/che-operator/pkg/deploy/identity-provider"
 	"github.com/eclipse-che/che-operator/pkg/deploy/postgres"
+	"github.com/eclipse-che/che-operator/pkg/deploy/tls"
 
 	orgv1 "github.com/eclipse-che/che-operator/api/v1"
 	"github.com/eclipse-che/che-operator/pkg/util"
@@ -29,13 +30,13 @@ import (
 )
 
 func (s Server) getDeploymentSpec() (*appsv1.Deployment, error) {
-	selfSignedCASecretExists, err := deploy.IsSelfSignedCASecretExists(s.deployContext)
+	selfSignedCASecretExists, err := tls.IsSelfSignedCASecretExists(s.deployContext)
 	if err != nil {
 		return nil, err
 	}
 
 	cmResourceVersions := GetCheConfigMapVersion(s.deployContext)
-	cmResourceVersions += "," + deploy.GetAdditionalCACertsConfigMapVersion(s.deployContext)
+	cmResourceVersions += "," + tls.GetAdditionalCACertsConfigMapVersion(s.deployContext)
 
 	terminationGracePeriodSeconds := int64(30)
 	cheFlavor := deploy.DefaultCheFlavor(s.deployContext.CheCluster)
@@ -50,7 +51,7 @@ func (s Server) getDeploymentSpec() (*appsv1.Deployment, error) {
 		VolumeSource: corev1.VolumeSource{
 			ConfigMap: &corev1.ConfigMapVolumeSource{
 				LocalObjectReference: corev1.LocalObjectReference{
-					Name: deploy.CheAllCACertsConfigMapName,
+					Name: tls.CheAllCACertsConfigMapName,
 				},
 			},
 		},
@@ -88,7 +89,7 @@ func (s Server) getDeploymentSpec() (*appsv1.Deployment, error) {
 				ConfigMapKeyRef: &corev1.ConfigMapKeySelector{
 					Key: "ca.crt",
 					LocalObjectReference: corev1.LocalObjectReference{
-						Name: "che-git-self-signed-cert",
+						Name: deploy.GitSelfSignedCertsConfigMapName,
 					},
 					Optional: &optionalEnv,
 				},
@@ -100,7 +101,7 @@ func (s Server) getDeploymentSpec() (*appsv1.Deployment, error) {
 				ConfigMapKeyRef: &corev1.ConfigMapKeySelector{
 					Key: "githost",
 					LocalObjectReference: corev1.LocalObjectReference{
-						Name: "che-git-self-signed-cert",
+						Name: deploy.GitSelfSignedCertsConfigMapName,
 					},
 					Optional: &optionalEnv,
 				},
@@ -161,7 +162,7 @@ func (s Server) getDeploymentSpec() (*appsv1.Deployment, error) {
 					FieldPath:  "metadata.namespace"}},
 		})
 
-	if util.IsNativeUserModeEnabled(s.deployContext.CheCluster) {
+	if util.IsOpenShift && s.deployContext.CheCluster.IsNativeUserModeEnabled() {
 		cheEnv = append(cheEnv, corev1.EnvVar{
 			Name:  "CHE_AUTH_NATIVEUSER",
 			Value: "true",
